# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"say_hello": "01_ts_demo.ipynb",
         "say_hello1": "01_ts_demo.ipynb"}

modules = ["ts_demo.py"]

doc_url = "https://nkhuyu-msft.github.io/ts_demo_lib/"

git_url = "https://github.com/nkhuyu-msft/ts_demo"

def custom_doc_links(name): return None



# AUTOGENERATED! DO NOT EDIT! File to edit: 01_ts_demo.ipynb (unless otherwise specified).

__all__ = ['say_hello', 'say_hello1']

# Cell
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'

# Cell
def say_hello1(to):
    "Say hello to somebody"
    return f'Hello {to}!'